@@ -1,9 +1,9 @@
 //
-// "$Id: Fluid_Image.cxx,v 1.7.2.9.2.15 2004/04/11 04:38:56 easysw Exp $"
+// "$Id: Fluid_Image.cxx 4607 2005-10-26 09:08:01Z matt $"
 //
 // Pixmap label support for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2004 by Bill Spitzak and others.
+// Copyright 1998-2005 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,7 +20,9 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
 #include <FL/Fl.H>
@@ -37,11 +39,11 @@ extern void goto_source_dir(); // in fluid.C
 extern void leave_source_dir(); // in fluid.C
 
 void Fluid_Image::image(Fl_Widget *o) {
-  o->image(img);
+  if (o->window() != o) o->image(img);
 }
 
 void Fluid_Image::deimage(Fl_Widget *o) {
-  o->deimage(img);
+  if (o->window() != o) o->deimage(img);
 }
 
 static int pixmap_header_written = 0;
@@ -92,7 +94,7 @@ void Fluid_Image::write_static() {
     }
     write_c("static unsigned char %s[] =\n",
 	    unique_id(this, "idata", fl_filename_name(name()), 0));
-    write_cstring(img->data()[0], ((img->w() + 7) / 8) * img->h());
+    write_cdata(img->data()[0], ((img->w() + 7) / 8) * img->h());
     write_c(";\n");
     write_c("static Fl_Bitmap %s(%s, %d, %d);\n",
 	    unique_id(this, "image", fl_filename_name(name()), 0),
@@ -107,7 +109,7 @@ void Fluid_Image::write_static() {
     }
     write_c("static unsigned char %s[] =\n",
 	    unique_id(this, "idata", fl_filename_name(name()), 0));
-    write_cstring(img->data()[0], (img->w() * img->d() + img->ld()) * img->h());
+    write_cdata(img->data()[0], (img->w() * img->d() + img->ld()) * img->h());
     write_c(";\n");
     write_c("static Fl_RGB_Image %s(%s, %d, %d, %d, %d);\n",
 	    unique_id(this, "image", fl_filename_name(name()), 0),
@@ -212,7 +214,9 @@ Fluid_Image::~Fluid_Image() {
 const char *ui_find_image_name;
 Fluid_Image *ui_find_image(const char *oldname) {
   goto_source_dir();
-  const char *name = fl_file_chooser("Image?","Image Files (*.{bm,bmp,gif,jpg,pbm,pgm,png,ppm,xbm,xpm})",oldname);
+  fl_file_chooser_ok_label("Use Image");
+  const char *name = fl_file_chooser("Image?","Image Files (*.{bm,bmp,gif,jpg,pbm,pgm,png,ppm,xbm,xpm})",oldname,1);
+  fl_file_chooser_ok_label(NULL);
   ui_find_image_name = name;
   Fluid_Image *ret = (name && *name) ? Fluid_Image::find(name) : 0;
   leave_source_dir();
@@ -221,5 +225,5 @@ Fluid_Image *ui_find_image(const char *oldname) {
 
 
 //
-// End of "$Id: Fluid_Image.cxx,v 1.7.2.9.2.15 2004/04/11 04:38:56 easysw Exp $".
+// End of "$Id: Fluid_Image.cxx 4607 2005-10-26 09:08:01Z matt $".
 //
