@@ -1,9 +1,9 @@
 //
-// "$Id: Fl.cxx,v 1.24.2.41.2.71 2004/11/23 19:50:58 easysw Exp $"
+// "$Id: Fl.cxx 4748 2006-01-15 02:26:54Z mike $"
 //
 // Main event handling code for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2004 by Bill Spitzak and others.
+// Copyright 1998-2006 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,7 +20,9 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
 // warning: the Apple Quartz version still uses some Quickdraw calls,
@@ -33,6 +35,7 @@
 #include <FL/x.H>
 #include <FL/Fl_Tooltip.H>
 #include <ctype.h>
+#include <stdio.h>
 #include <stdlib.h>
 #include "flstring.h"
 
@@ -40,6 +43,14 @@
 #  include <stdio.h>
 #endif // DEBUG
 
+#ifdef WIN32
+#  include <ole2.h>
+void fl_free_fonts(void);
+HBRUSH fl_brush_action(int action);
+void fl_cleanup_pens(void);
+void fl_release_dc(HWND,HDC);
+void fl_cleanup_dc_list(void);
+#endif // WIN32
 
 //
 // Globals...
@@ -94,6 +105,26 @@ int Fl::event_inside(const Fl_Widget *o) /*const*/ {
   return (mx >= 0 && mx < o->w() && my >= 0 && my < o->h());
 }
 
+//
+//
+// timer support
+//
+
+#ifdef WIN32
+
+/// implementation in Fl_win32.cxx
+
+#elif defined(__APPLE__)
+
+/// implementation in Fl_mac.cxx
+
+#else
+
+//
+// X11 timers
+//
+
+
 ////////////////////////////////////////////////////////////////
 // Timeouts are stored in a sorted list, so only the first one needs
 // to be checked to see if any should be called.
@@ -105,10 +136,9 @@ struct Timeout {
   Timeout* next;
 };
 static Timeout* first_timeout, *free_timeout;
+static int first_timeout_count, free_timeout_count;
 
-#ifndef WIN32
-#  include <sys/time.h>
-#endif
+#include <sys/time.h>
 
 // I avoid the overhead of getting the current time when we have no
 // timeouts by setting this flag instead of getting the time.
@@ -117,12 +147,6 @@ static Timeout* first_timeout, *free_timeout;
 static char reset_clock = 1;
 
 static void elapse_timeouts() {
-#ifdef WIN32
-  unsigned long newclock = GetTickCount();
-  static unsigned long prevclock;
-  double elapsed = (newclock-prevclock)/1000.0;
-  prevclock = newclock;
-#else
   static struct timeval prevclock;
   struct timeval newclock;
   gettimeofday(&newclock, NULL);
@@ -130,7 +154,6 @@ static void elapse_timeouts() {
     (newclock.tv_usec - prevclock.tv_usec)/1000000.0;
   prevclock.tv_sec = newclock.tv_sec;
   prevclock.tv_usec = newclock.tv_usec;
-#endif
   if (reset_clock) {
     reset_clock = 0;
   } else if (elapsed > 0) {
@@ -152,8 +175,12 @@ void Fl::add_timeout(double time, Fl_Timeout_Handler cb, void *argp) {
 void Fl::repeat_timeout(double time, Fl_Timeout_Handler cb, void *argp) {
   time += missed_timeout_by; if (time < -.05) time = 0;
   Timeout* t = free_timeout;
-  if (t) free_timeout = t->next;
-  else t = new Timeout;
+  if (t) {
+      free_timeout = t->next;
+      --free_timeout_count;
+  } else {
+      t = new Timeout;
+  }
   t->time = time;
   t->cb = cb;
   t->arg = argp;
@@ -185,6 +212,8 @@ void Fl::remove_timeout(Fl_Timeout_Handler cb, void *argp) {
   }
 }
 
+#endif
+
 ////////////////////////////////////////////////////////////////
 // Checks are just stored in a list. They are called in the reverse
 // order that they were added (this may change in the future).
@@ -198,7 +227,7 @@ struct Check {
   void* arg;
   Check* next;
 };
-static Check* first_check, *next_check, *free_check;
+static Check *first_check, *next_check, *free_check;
 
 void Fl::add_check(Fl_Timeout_Handler cb, void *argp) {
   Check* t = free_check;
@@ -225,6 +254,24 @@ void Fl::remove_check(Fl_Timeout_Handler cb, void *argp) {
   }
 }
 
+#if !defined(__APPLE__)
+static void run_checks()
+{
+  // checks are a bit messy so that add/remove and wait may be called
+  // from inside them without causing an infinite loop:
+  if (next_check == first_check) {
+    while (next_check) {
+      Check* checkp = next_check;
+      next_check = checkp->next;
+      (checkp->cb)(checkp->arg);
+    }
+    next_check = first_check;
+  }
+}
+#endif // !__APPLE__
+
+static char in_idle;
+
 ////////////////////////////////////////////////////////////////
 // wait/run/check/ready:
 
@@ -233,11 +280,30 @@ void (*Fl::idle)(); // see Fl_add_idle.cxx for the add/remove functions
 extern int fl_ready(); // in Fl_<platform>.cxx
 extern int fl_wait(double time); // in Fl_<platform>.cxx
 
-static char in_idle;
-
 double Fl::wait(double time_to_wait) {
+  // delete all widgets that were listed during callbacks
   do_widget_deletion();
 
+#ifdef WIN32
+
+  return fl_wait(time_to_wait);
+
+#elif defined(__APPLE__)
+
+  flush();
+  if (idle) {
+    if (!in_idle) {
+      in_idle = 1;
+      idle();
+      in_idle = 0;
+    }
+    // the idle function may turn off idle, we can then wait:
+    if (idle) time_to_wait = 0.0;
+  }
+  return fl_wait(time_to_wait);
+
+#else
+
   if (first_timeout) {
     elapse_timeouts();
     Timeout *t;
@@ -251,22 +317,15 @@ double Fl::wait(double time_to_wait) {
       first_timeout = t->next;
       t->next = free_timeout;
       free_timeout = t;
+      ++free_timeout_count;
+      --first_timeout_count;
       // Now it is safe for the callback to do add_timeout:
       cb(argp);
     }
   } else {
     reset_clock = 1; // we are not going to check the clock
   }
-  // checks are a bit messy so that add/remove and wait may be called
-  // from inside them without causing an infinite loop:
-  if (next_check == first_check) {
-    while (next_check) {
-      Check* checkp = next_check;
-      next_check = checkp->next;
-      (checkp->cb)(checkp->arg);
-    }
-    next_check = first_check;
-  }
+  run_checks();
 //  if (idle && !fl_ready()) {
   if (idle) {
     if (!in_idle) {
@@ -289,16 +348,25 @@ double Fl::wait(double time_to_wait) {
     flush();
     return fl_wait(time_to_wait);
   }
+#endif
 }
 
 #define FOREVER 1e20
 
 int Fl::run() {
   while (Fl_X::first) wait(FOREVER);
+#ifdef WIN32
+  fl_free_fonts();        // do some WIN32 cleanup
+  fl_cleanup_pens();
+  OleUninitialize();
+  fl_brush_action(1);
+  fl_cleanup_dc_list();
+#endif
   return 0;
 }
 
 int Fl::wait() {
+  if (!Fl_X::first) return 0;
   wait(FOREVER);
   return Fl_X::first != 0; // return true if there is a window
 }
@@ -308,15 +376,15 @@ int Fl::check() {
   return Fl_X::first != 0; // return true if there is a window
 }
 
-extern int fl_ready();
-
 int Fl::ready() {
+#if ! defined( WIN32 )  &&  ! defined(__APPLE__)
   if (first_timeout) {
     elapse_timeouts();
     if (first_timeout->time <= 0) return 1;
   } else {
     reset_clock = 1;
   }
+#endif
   return fl_ready();
 }
 
@@ -447,10 +515,13 @@ void Fl::focus(Fl_Widget *o) {
     Fl::compose_reset();
     focus_ = o;
     fl_oldfocus = 0;
+    int old_event = e_number;
+    e_number = FL_UNFOCUS;
     for (; p; p = p->parent()) {
       p->handle(FL_UNFOCUS);
       fl_oldfocus = p;
     }
+    e_number = old_event;
   }
 }
 
@@ -461,9 +532,12 @@ void Fl::belowmouse(Fl_Widget *o) {
   Fl_Widget *p = belowmouse_;
   if (o != p) {
     belowmouse_ = o;
+    int old_event = e_number;
+    e_number = dnd_flag ? FL_DND_LEAVE : FL_LEAVE;
     for (; p && !p->contains(o); p = p->parent()) {
-      p->handle(dnd_flag ? FL_DND_LEAVE : FL_LEAVE);
+      p->handle(e_number);
     }
+    e_number = old_event;
   }
 }
 
@@ -497,6 +571,7 @@ void fl_fix_focus() {
   // set focus based on Fl::modal() and fl_xfocus
   Fl_Widget* w = fl_xfocus;
   if (w) {
+    int saved = Fl::e_keysym;
     if (Fl::e_keysym < (FL_Button + FL_LEFT_MOUSE) ||
         Fl::e_keysym > (FL_Button + FL_RIGHT_MOUSE))
       Fl::e_keysym = 0; // make sure widgets don't think a keystroke moved focus
@@ -504,6 +579,7 @@ void fl_fix_focus() {
     if (Fl::modal()) w = Fl::modal();
     if (!w->contains(Fl::focus()))
       if (!w->take_focus()) Fl::focus(w);
+    Fl::e_keysym = saved;
   } else
     Fl::focus(0);
 
@@ -516,13 +592,17 @@ void fl_fix_focus() {
     if (w) {
       if (Fl::modal()) w = Fl::modal();
       if (!w->contains(Fl::belowmouse())) {
-	w->handle(FL_ENTER);
+        int old_event = Fl::e_number;
+	w->handle(Fl::e_number = FL_ENTER);
+	Fl::e_number = old_event;
 	if (!w->contains(Fl::belowmouse())) Fl::belowmouse(w);
       } else {
 	// send a FL_MOVE event so the enter/leave state is up to date
 	Fl::e_x = Fl::e_x_root-fl_xmousewin->x();
 	Fl::e_y = Fl::e_y_root-fl_xmousewin->y();
-	w->handle(FL_MOVE);
+        int old_event = Fl::e_number;
+	w->handle(Fl::e_number = FL_MOVE);
+	Fl::e_number = old_event;
       }
     } else {
       Fl::belowmouse(0);
@@ -568,6 +648,7 @@ void fl_throw_focus(Fl_Widget *o) {
 // window the event was posted to by X:
 static int send(int event, Fl_Widget* to, Fl_Window* window) {
   int dx, dy;
+  int old_event = Fl::e_number;
   if (window) {
     dx = window->x();
     dy = window->y();
@@ -578,7 +659,8 @@ static int send(int event, Fl_Widget* to, Fl_Window* window) {
     if (w->type()>=FL_WINDOW) {dx -= w->x(); dy -= w->y();}
   int save_x = Fl::e_x; Fl::e_x += dx;
   int save_y = Fl::e_y; Fl::e_y += dy;
-  int ret = to->handle(event);
+  int ret = to->handle(Fl::e_number = event);
+  Fl::e_number = old_event;
   Fl::e_y = save_y;
   Fl::e_x = save_x;
   return ret;
@@ -696,7 +778,7 @@ int Fl::handle(int e, Fl_Window* window)
 
     // and then try a shortcut with the case of the text swapped, by
     // changing the text and falling through to FL_SHORTCUT case:
-    {char* c = (char*)event_text(); // cast away const
+    {unsigned char* c = (unsigned char*)event_text(); // cast away const
     if (!isalpha(*c)) return 0;
     *c = isupper(*c) ? tolower(*c) : toupper(*c);}
     e_number = e = FL_SHORTCUT;
@@ -745,9 +827,11 @@ int Fl::handle(int e, Fl_Window* window)
   case FL_MOUSEWHEEL:
     fl_xfocus = window; // this should not happen!  But maybe it does:
 
-    // Try it as keystroke, sending it to focus and all parents:
-    for (wi = grab() ? grab() : focus(); wi; wi = wi->parent())
-      if (send(FL_MOUSEWHEEL, wi, window)) return 1;
+    // Try sending it to the grab and then the window:
+    if (grab()) {
+      if (send(FL_MOUSEWHEEL, grab(), window)) return 1;
+    }
+    if (send(FL_MOUSEWHEEL, window, window)) return 1;
   default:
     break;
   }
@@ -817,12 +901,24 @@ void Fl_Window::hide() {
   handle(FL_HIDE);
 
 #ifdef WIN32
-  if (ip->private_dc) ReleaseDC(ip->xid,ip->private_dc);
-  if (ip->xid == fl_window && fl_gc) {
-    ReleaseDC(fl_window, fl_gc);
-    fl_window = (HWND)-1;
-    fl_gc = 0;
+  // this little trick keeps the current clipboard alive, even if we are about
+  // to destroy the window that owns the selection.
+  if (GetClipboardOwner()==ip->xid) {
+    Fl_Window *w1 = Fl::first_window();
+    if (w1 && OpenClipboard(fl_xid(w1))) {
+      EmptyClipboard();
+      SetClipboardData(CF_TEXT, NULL);
+      CloseClipboard();
+    }
   }
+  // Send a message to myself so that I'll get out of the event loop...
+  PostMessage(ip->xid, WM_APP, 0, 0);
+  if (ip->private_dc) fl_release_dc(ip->xid, ip->private_dc);
+    if (ip->xid == fl_window && fl_gc) {
+      fl_release_dc(fl_window, fl_gc);
+      fl_window = (HWND)-1;
+      fl_gc = 0;
+    }
 #elif defined(__APPLE_QD__)
   if ( ip->xid == fl_window )
     fl_window = 0;
@@ -830,11 +926,13 @@ void Fl_Window::hide() {
   Fl_X::q_release_context(ip);
   if ( ip->xid == fl_window )
     fl_window = 0;
-#else
-  if (ip->region) XDestroyRegion(ip->region);
 #endif
 
-#ifdef __APPLE_QD__
+  if (ip->region) XDestroyRegion(ip->region);
+
+#ifdef WIN32
+  XDestroyWindow(fl_display, ip->xid);
+#elif defined(__APPLE_QD__)
   if ( !parent() ) // don't destroy shared windows!
   {
     //+ RemoveTrackingHandler( dndTrackingHandler, ip->xid );
@@ -1053,6 +1151,11 @@ void Fl_Window::flush() {
   draw();
 }
 
+#ifdef WIN32
+#  include "Fl_win32.cxx"
+#elif defined(__APPLE__)
+#  include "Fl_mac.cxx"
+#endif
 
 //
 // The following methods allow callbacks to schedule the deletion of
@@ -1063,8 +1166,8 @@ static int		num_dwidgets = 0, alloc_dwidgets = 0;
 static Fl_Widget	**dwidgets = 0;
 
 void
-Fl::delete_widget(Fl_Widget *w) {
-  if (!w) return;
+Fl::delete_widget(Fl_Widget *wi) {
+  if (!wi) return;
 
   if (num_dwidgets >= alloc_dwidgets) {
     Fl_Widget	**temp;
@@ -1079,7 +1182,7 @@ Fl::delete_widget(Fl_Widget *w) {
     alloc_dwidgets += 10;
   }
 
-  dwidgets[num_dwidgets] = w;
+  dwidgets[num_dwidgets] = wi;
   num_dwidgets ++;
 }
 
@@ -1096,5 +1199,5 @@ Fl::do_widget_deletion() {
 
 
 //
-// End of "$Id: Fl.cxx,v 1.24.2.41.2.71 2004/11/23 19:50:58 easysw Exp $".
+// End of "$Id: Fl.cxx 4748 2006-01-15 02:26:54Z mike $".
 //
