@@ -1,9 +1,9 @@
 //
-// "$Id: Fl_Box.cxx,v 1.4.2.3 2001/01/22 15:13:39 easysw Exp $"
+// "$Id: Fl_Box.cxx 4288 2005-04-16 00:13:17Z mike $"
 //
 // Box widget for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2001 by Bill Spitzak and others.
+// Copyright 1998-2005 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,19 +20,25 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
 #include <FL/Fl_Widget.H>
 #include <FL/Fl_Box.H>
 
-// MRS - shouldn't we inline this?
-
 void Fl_Box::draw() {
   draw_box();
   draw_label();
 }
 
+int Fl_Box::handle(int event) {
+  if (event == FL_ENTER || event == FL_LEAVE) return 1;
+  else return 0;
+}
+
+
 //
-// End of "$Id: Fl_Box.cxx,v 1.4.2.3 2001/01/22 15:13:39 easysw Exp $".
+// End of "$Id: Fl_Box.cxx 4288 2005-04-16 00:13:17Z mike $".
 //
