@@ -1,9 +1,9 @@
 //
-// "$Id: Fl_Check_Button.cxx,v 1.4.2.3.2.6 2004/04/11 04:38:57 easysw Exp $"
+// "$Id: Fl_Check_Button.cxx 4627 2005-11-02 14:18:32Z matt $"
 //
 // Check button widget for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2004 by Bill Spitzak and others.
+// Copyright 1998-2005 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,7 +20,9 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
 #include <FL/Fl.H>
@@ -34,5 +36,5 @@ Fl_Check_Button::Fl_Check_Button(int X, int Y, int W, int H, const char *l)
 : Fl_Light_Button(X, Y, W, H, l) {
   box(FL_NO_BOX);
   down_box(FL_DOWN_BOX);
-  selection_color(FL_BLACK);
+  selection_color(FL_FOREGROUND_COLOR);
 }
