@@ -1,9 +1,9 @@
 //
-// "$Id: Fl_Group.cxx,v 1.8.2.8.2.25 2004/10/18 20:22:22 easysw Exp $"
+// "$Id: Fl_Group.cxx 4288 2005-04-16 00:13:17Z mike $"
 //
 // Group widget for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2004 by Bill Spitzak and others.
+// Copyright 1998-2005 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,7 +20,9 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
 // The Fl_Group is the only defined container type in FLTK.
@@ -162,7 +164,7 @@ int Fl_Group::handle(int event) {
 	if (o->contains(Fl::belowmouse())) {
 	  return send(o,FL_MOVE);
 	} else {
-	  if (!o->contains(Fl::belowmouse())) Fl::belowmouse(o);
+	  Fl::belowmouse(o);
 	  if (send(o,FL_ENTER)) return 1;
 	}
       }
@@ -213,6 +215,19 @@ int Fl_Group::handle(int event) {
     }
     return 0;
 
+  case FL_MOUSEWHEEL:
+    for (i = children(); i--;) {
+      o = a[i];
+      if (o->takesevents() && Fl::event_inside(o) && send(o,FL_MOUSEWHEEL))
+	return 1;
+    }
+    for (i = children(); i--;) {
+      o = a[i];
+      if (o->takesevents() && !Fl::event_inside(o) && send(o,FL_MOUSEWHEEL))
+	return 1;
+    }
+    return 0;
+
   case FL_DEACTIVATE:
   case FL_ACTIVATE:
     for (i = children(); i--;) {
@@ -227,7 +242,9 @@ int Fl_Group::handle(int event) {
       o = *a++;
       if (event == FL_HIDE && o == Fl::focus()) {
         // Give up input focus...
-        o->handle(FL_UNFOCUS);
+	int old_event = Fl::e_number;
+        o->handle(Fl::e_number = FL_UNFOCUS);
+	Fl::e_number = old_event;
 	Fl::focus(0);
       }
       if (o->visible()) o->handle(event);
@@ -591,5 +608,5 @@ void Fl_Group::draw_outside_label(const Fl_Widget& widget) const {
 }
 
 //
-// End of "$Id: Fl_Group.cxx,v 1.8.2.8.2.25 2004/10/18 20:22:22 easysw Exp $".
+// End of "$Id: Fl_Group.cxx 4288 2005-04-16 00:13:17Z mike $".
 //
