@@ -1,9 +1,9 @@
 //
-// "$Id: Fl_Image.cxx,v 1.5.2.3.2.38 2004/09/24 16:00:10 easysw Exp $"
+// "$Id: Fl_Image.cxx 4621 2005-11-02 11:30:41Z matt $"
 //
 // Image drawing code for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2004 by Bill Spitzak and others.
+// Copyright 1998-2005 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,7 +20,9 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
 #include <FL/Fl.H>
@@ -31,6 +33,9 @@
 #include <FL/Fl_Image.H>
 #include "flstring.h"
 
+#ifdef WIN32
+void fl_release_dc(HWND, HDC); // from Fl_win32.cxx
+#endif
 
 void fl_restore_clip(); // from fl_rect.cxx
 
@@ -50,7 +55,7 @@ void Fl_Image::draw(int XP, int YP, int, int, int, int) {
 
 void Fl_Image::draw_empty(int X, int Y) {
   if (w() > 0 && h() > 0) {
-    fl_color(FL_BLACK);
+    fl_color(FL_FOREGROUND_COLOR);
     fl_rect(X, Y, w(), h());
     fl_line(X, Y, X + w() - 1, Y + h() - 1);
     fl_line(X, Y + h() - 1, X + w() - 1, Y);
@@ -345,10 +350,12 @@ void Fl_RGB_Image::draw(int XP, int YP, int WP, int HP, int cx, int cy) {
 #ifdef WIN32
   if (mask) {
     HDC new_gc = CreateCompatibleDC(fl_gc);
+    int save = SaveDC(new_gc);
     SelectObject(new_gc, (void*)mask);
     BitBlt(fl_gc, X, Y, W, H, new_gc, cx, cy, SRCAND);
     SelectObject(new_gc, (void*)id);
     BitBlt(fl_gc, X, Y, W, H, new_gc, cx, cy, SRCPAINT);
+    RestoreDC(new_gc,save);
     DeleteDC(new_gc);
   } else {
     fl_copy_offscreen(X, Y, W, H, (Fl_Offscreen)id, cx, cy);
@@ -428,5 +435,5 @@ void Fl_RGB_Image::label(Fl_Menu_Item* m) {
 
 
 //
-// End of "$Id: Fl_Image.cxx,v 1.5.2.3.2.38 2004/09/24 16:00:10 easysw Exp $".
+// End of "$Id: Fl_Image.cxx 4621 2005-11-02 11:30:41Z matt $".
 //
