@@ -1,9 +1,9 @@
 //
-// "$Id: Fl_PNG_Image.cxx,v 1.1.2.12 2004/10/18 20:22:24 easysw Exp $"
+// "$Id: Fl_PNG_Image.cxx 4288 2005-04-16 00:13:17Z mike $"
 //
 // Fl_PNG_Image routines.
 //
-// Copyright 1997-2004 by Easy Software Products.
+// Copyright 1997-2005 by Easy Software Products.
 // Image support donated by Matthias Melcher, Copyright 2000.
 //
 // This library is free software; you can redistribute it and/or
@@ -21,7 +21,9 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 // Contents:
 //
@@ -47,7 +49,7 @@ extern "C"
 #  else
 #    include <libpng/png.h>
 #  endif // HAVE_PNG_H
-#endif // HAVE_LIBPNG ** HAVE_LIBZ
+#endif // HAVE_LIBPNG && HAVE_LIBZ
 }
 
 
@@ -149,5 +151,5 @@ Fl_PNG_Image::Fl_PNG_Image(const char *png) // I - File to read
 
 
 //
-// End of "$Id: Fl_PNG_Image.cxx,v 1.1.2.12 2004/10/18 20:22:24 easysw Exp $".
+// End of "$Id: Fl_PNG_Image.cxx 4288 2005-04-16 00:13:17Z mike $".
 //
