@@ -1,9 +1,9 @@
 //
-// "$Id: Fl_Pack.cxx,v 1.6.2.4 2001/01/22 15:13:40 easysw Exp $"
+// "$Id: Fl_Pack.cxx 4288 2005-04-16 00:13:17Z mike $"
 //
 // Packing widget for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2001 by Bill Spitzak and others.
+// Copyright 1998-2005 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,7 +20,9 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
 // Based on code by Curtis Edwards
@@ -32,8 +34,8 @@
 #include <FL/Fl_Pack.H>
 #include <FL/fl_draw.H>
 
-Fl_Pack::Fl_Pack(int x,int y,int w ,int h,const char *l)
-: Fl_Group(x, y, w, h, l) {
+Fl_Pack::Fl_Pack(int X, int Y, int W, int H,const char *l)
+: Fl_Group(X, Y, W, H, l) {
   resizable(0);
   spacing_ = 0;
   // type(VERTICAL); // already set like this
@@ -44,10 +46,30 @@ void Fl_Pack::draw() {
   int ty = y()+Fl::box_dy(box());
   int tw = w()-Fl::box_dw(box());
   int th = h()-Fl::box_dh(box());
-  int current_position = horizontal() ? tx : ty;
+  int rw, rh;
+  int current_position = (horizontal() ? tx : ty) + spacing_ / 2;
   int maximum_position = current_position;
   uchar d = damage();
   Fl_Widget*const* a = array();
+  if (horizontal()) {
+    rw = -spacing_;
+    rh = th;
+
+    for (int i = children(); i--;)
+      if (child(i)->visible()) {
+	if (child(i) != this->resizable()) rw += child(i)->w();
+	rw += spacing_;
+      }
+  } else {
+    rw = tw;
+    rh = -spacing_;
+
+    for (int i = children(); i--;)
+      if (child(i)->visible()) {
+	if (child(i) != this->resizable()) rh += child(i)->h();
+	rh += spacing_;
+      }
+  }
   for (int i = children(); i--;) {
     Fl_Widget* o = *a++;
     if (o->visible()) {
@@ -66,11 +88,11 @@ void Fl_Pack::draw() {
       // Last child, if resizable, takes all remaining room
       if(i == 0 && o == this->resizable()) {
        if(horizontal())
-         W = this->w() - Fl::box_dw(box()) - maximum_position;
+         W = tw - rw;
        else
-         H = this->h() - Fl::box_dh(box()) - maximum_position;
+         H = th - rh;
       }
-      if (spacing_ && current_position>maximum_position &&
+      if (spacing_ && current_position>maximum_position && box() &&
   	  (X != o->x() || Y != o->y() || d&FL_DAMAGE_ALL)) {
         fl_color(color());
         if (horizontal())
@@ -82,7 +104,10 @@ void Fl_Pack::draw() {
         o->resize(X,Y,W,H);
         o->clear_damage(FL_DAMAGE_ALL);
       }
-      if (d&FL_DAMAGE_ALL) draw_child(*o); else update_child(*o);
+      if (d&FL_DAMAGE_ALL) {
+        draw_child(*o);
+        draw_outside_label(*o);
+      } else update_child(*o);
       // child's draw() can change it's size, so use new size:
       current_position += (horizontal() ? o->w() : o->h());
       if (current_position > maximum_position)
@@ -92,13 +117,13 @@ void Fl_Pack::draw() {
   }
 
   if (horizontal()) {
-    if (maximum_position < tx+tw) {
+    if (maximum_position < tx+tw && box()) {
       fl_color(color());
       fl_rectf(maximum_position, ty, tx+tw-maximum_position, th);
     }
     tw = maximum_position-tx;
   } else {
-    if (maximum_position < ty+th) {
+    if (maximum_position < ty+th && box()) {
       fl_color(color());
       fl_rectf(tx, maximum_position, tw, ty+th-maximum_position);
     }
@@ -107,10 +132,16 @@ void Fl_Pack::draw() {
 
   tw += Fl::box_dw(box()); if (tw <= 0) tw = 1;
   th += Fl::box_dh(box()); if (th <= 0) th = 1;
-  if (tw != w() || th != h()) {Fl_Widget::resize(x(),y(),tw,th); d = FL_DAMAGE_ALL;}
-  if (d&FL_DAMAGE_ALL) draw_box();
+  if (tw != w() || th != h()) {
+    Fl_Widget::resize(x(),y(),tw,th);
+    d = FL_DAMAGE_ALL;
+  }
+  if (d&FL_DAMAGE_ALL) {
+    draw_box();
+    draw_label();
+  }
 }
 
 //
-// End of "$Id: Fl_Pack.cxx,v 1.6.2.4 2001/01/22 15:13:40 easysw Exp $".
+// End of "$Id: Fl_Pack.cxx 4288 2005-04-16 00:13:17Z mike $".
 //
