@@ -1,9 +1,9 @@
 //
-// "$Id: Fl_Value_Output.cxx,v 1.6.2.3.2.8 2004/04/11 04:38:58 easysw Exp $"
+// "$Id: Fl_Value_Output.cxx 4609 2005-10-30 17:42:21Z mike $"
 //
 // Value output widget for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2004 by Bill Spitzak and others.
+// Copyright 1998-2005 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,7 +20,9 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
 // Fltk widget for drag-adjusting a floating point value.
@@ -92,10 +94,10 @@ Fl_Value_Output::Fl_Value_Output(int X, int Y, int W, int H,const char *l)
   align(FL_ALIGN_LEFT);
   textfont_ = FL_HELVETICA;
   textsize_ = (uchar)FL_NORMAL_SIZE;
-  textcolor_ = FL_BLACK;
+  textcolor_ = FL_FOREGROUND_COLOR;
   soft_ = 0;
 }
 
 //
-// End of "$Id: Fl_Value_Output.cxx,v 1.6.2.3.2.8 2004/04/11 04:38:58 easysw Exp $".
+// End of "$Id: Fl_Value_Output.cxx 4609 2005-10-30 17:42:21Z mike $".
 //
