@@ -1,9 +1,9 @@
 //
-// "$Id: Fl_Value_Slider.cxx,v 1.5.2.4 2001/01/22 15:13:40 easysw Exp $"
+// "$Id: Fl_Value_Slider.cxx 4609 2005-10-30 17:42:21Z mike $"
 //
 // Value slider widget for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2001 by Bill Spitzak and others.
+// Copyright 1998-2005 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,7 +20,9 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
 #include <FL/Fl.H>
@@ -28,12 +30,12 @@
 #include <FL/fl_draw.H>
 #include <math.h>
 
-Fl_Value_Slider::Fl_Value_Slider(int x,int y,int w,int h, const char*l)
-: Fl_Slider(x,y,w,h,l) {
+Fl_Value_Slider::Fl_Value_Slider(int X, int Y, int W, int H, const char*l)
+: Fl_Slider(X,Y,W,H,l) {
   step(1,100);
   textfont_ = FL_HELVETICA;
   textsize_ = 10;
-  textcolor_ = FL_BLACK;
+  textcolor_ = FL_FOREGROUND_COLOR;
 }
 
 void Fl_Value_Slider::draw() {
@@ -53,11 +55,15 @@ void Fl_Value_Slider::draw() {
   char buf[128];
   format(buf);
   fl_font(textfont(), textsize());
-  fl_color(active_r() ? textcolor() : inactive(textcolor()));
+  fl_color(active_r() ? textcolor() : fl_inactive(textcolor()));
   fl_draw(buf, bxx, byy, bww, bhh, FL_ALIGN_CLIP);
 }
 
 int Fl_Value_Slider::handle(int event) {
+  if (event == FL_PUSH && Fl::visible_focus()) {
+    Fl::focus(this);
+    redraw();
+  }
   int sxx = x(), syy = y(), sww = w(), shh = h();
   if (horizontal()) {
     sxx += 35; sww -= 35;
@@ -72,5 +78,5 @@ int Fl_Value_Slider::handle(int event) {
 }
 
 //
-// End of "$Id: Fl_Value_Slider.cxx,v 1.5.2.4 2001/01/22 15:13:40 easysw Exp $".
+// End of "$Id: Fl_Value_Slider.cxx 4609 2005-10-30 17:42:21Z mike $".
 //
