@@ -1,9 +1,9 @@
 //
-// "$Id: Fl_Window.cxx,v 1.6.2.3.2.12 2004/04/11 04:38:58 easysw Exp $"
+// "$Id: Fl_Window.cxx 4711 2005-12-14 13:51:51Z matt $"
 //
 // Window widget class for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2004 by Bill Spitzak and others.
+// Copyright 1998-2005 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,7 +20,9 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
 // The Fl_Window is a window in the fltk library.
@@ -30,6 +32,12 @@
 
 #include <FL/Fl.H>
 #include <FL/Fl_Window.H>
+#include <stdlib.h>
+#include "flstring.h"
+
+#ifdef __APPLE_QUARTZ__
+#include <FL/fl_draw.h>
+#endif
 
 void Fl_Window::_Fl_Window() {
   type(FL_WINDOW);
@@ -92,20 +100,57 @@ int Fl_Window::y_root() const {
 
 void Fl_Window::draw() {
   const char *savelabel = label();
+  uchar saveflags = flags();
   int savex = x(); x(0);
   int savey = y(); y(0);
   // Make sure we don't draw the window title in the window background...
   Fl_Widget::label(0);
   Fl_Group::draw();
+#ifdef __APPLE_QUARTZ__
+  if (!parent() && resizable()) {
+    int dx = Fl::box_dw(box())-Fl::box_dx(box());
+    int dy = Fl::box_dh(box())-Fl::box_dy(box());
+    if (dx<=0) dx = 1;
+    if (dy<=0) dy = 1;
+    int x1 = w()-dx-1, x2 = x1, y1 = h()-dx-1, y2 = y1;
+    Fl_Color c[4] = {
+      color(),
+      fl_color_average(color(), FL_WHITE, 0.7f),
+      fl_color_average(color(), FL_BLACK, 0.6f),
+      fl_color_average(color(), FL_BLACK, 0.8f),
+    };
+    int i;
+    for (i=dx; i<12; i++) {
+      fl_color(c[i&3]);
+      fl_line(x1--, y1, x2, y2--);
+    }
+  }
+#endif
   // Restore the label...
   Fl_Widget::label(savelabel);
+  set_flag(saveflags);
   y(savey);
   x(savex);
 }
 
 void Fl_Window::label(const char *name) {label(name, iconlabel());}
 
-void Fl_Window::iconlabel(const char *iname) {label(label(), iname);}
+void Fl_Window::copy_label(const char *a) {
+  if (flags() & COPIED_LABEL) {
+    free((void *)label());
+    clear_flag(COPIED_LABEL);
+  }
+  if (a) a = strdup(a);
+  label(a, iconlabel());
+  set_flag(COPIED_LABEL);
+}
+
+
+void Fl_Window::iconlabel(const char *iname) {
+  uchar saveflags = flags();
+  label(label(), iname);
+  set_flag(saveflags);
+}
 
 // the Fl::atclose pointer is provided for back compatability.  You
 // can now just change the callback for the window instead.
@@ -127,5 +172,5 @@ Fl_Window *Fl_Window::current() {
 
 
 //
-// End of "$Id: Fl_Window.cxx,v 1.6.2.3.2.12 2004/04/11 04:38:58 easysw Exp $".
+// End of "$Id: Fl_Window.cxx 4711 2005-12-14 13:51:51Z matt $".
 //
