@@ -1,9 +1,9 @@
 //
-// "$Id: Fl_get_system_colors.cxx,v 1.6.2.7.2.26 2004/05/25 21:06:19 easysw Exp $"
+// "$Id: Fl_get_system_colors.cxx 4705 2005-12-14 01:58:03Z mike $"
 //
 // System color support for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2004 by Bill Spitzak and others.
+// Copyright 1998-2005 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,7 +20,9 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
 #include <FL/Fl.H>
@@ -38,6 +40,11 @@
 extern "C" int putenv(const char*);
 #endif // __APPLE__ && __MWERKS__
 
+#if defined(WIN32) && !defined(__CYGWIN__)
+// Visual C++ 2005 incorrectly displays a warning about the use of POSIX APIs
+// on Windows, which is supposed to be POSIX compliant...
+#  define putenv _putenv
+#endif // WIN32 && !__CYGWIN__
 
 static char	fl_bg_set = 0;
 static char	fl_bg2_set = 0;
@@ -299,8 +306,8 @@ int Fl::reload_scheme() {
     set_boxtype(FL_DOWN_BOX,        FL_PLASTIC_DOWN_BOX);
     set_boxtype(FL_THIN_UP_BOX,     FL_PLASTIC_THIN_UP_BOX);
     set_boxtype(FL_THIN_DOWN_BOX,   FL_PLASTIC_THIN_DOWN_BOX);
-    set_boxtype(_FL_ROUND_UP_BOX,   FL_PLASTIC_UP_BOX);
-    set_boxtype(_FL_ROUND_DOWN_BOX, FL_PLASTIC_UP_BOX);
+    set_boxtype(_FL_ROUND_UP_BOX,   FL_PLASTIC_ROUND_UP_BOX);
+    set_boxtype(_FL_ROUND_DOWN_BOX, FL_PLASTIC_ROUND_DOWN_BOX);
   } else {
     // Use the standard FLTK look-n-feel...
     if (scheme_bg_) {
@@ -334,5 +341,5 @@ int Fl::reload_scheme() {
 
 
 //
-// End of "$Id: Fl_get_system_colors.cxx,v 1.6.2.7.2.26 2004/05/25 21:06:19 easysw Exp $".
+// End of "$Id: Fl_get_system_colors.cxx 4705 2005-12-14 01:58:03Z mike $".
 //
