@@ -1,9 +1,9 @@
 //
-// "$Id: Fl_x.cxx,v 1.24.2.24.2.40 2004/11/20 13:52:47 easysw Exp $"
+// "$Id: Fl_x.cxx 4748 2006-01-15 02:26:54Z mike $"
 //
 // X specific code for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2004 by Bill Spitzak and others.
+// Copyright 1998-2006 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,13 +20,15 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
 #ifdef WIN32
-#  include "Fl_win32.cxx"
+//#  include "Fl_win32.cxx"
 #elif defined(__APPLE__)
-#  include "Fl_mac.cxx"
+//#  include "Fl_mac.cxx"
 #else
 
 #  define CONSOLIDATE_MOTION 1
@@ -284,6 +286,7 @@ Atom fl_XdndStatus;
 Atom fl_XdndActionCopy;
 Atom fl_XdndFinished;
 //Atom fl_XdndProxy;
+Atom fl_XdndURIList;
 
 
 static void fd_callback(int,void *) {
@@ -337,6 +340,8 @@ void fl_open_display(Display* d) {
   fl_XdndActionCopy     = XInternAtom(d, "XdndActionCopy",	0);
   fl_XdndFinished       = XInternAtom(d, "XdndFinished",	0);
   //fl_XdndProxy        = XInternAtom(d, "XdndProxy",		0);
+  fl_XdndEnter          = XInternAtom(d, "XdndEnter",		0);
+  fl_XdndURIList        = XInternAtom(d, "text/uri-list",	0);
 
   Fl::add_fd(ConnectionNumber(d), POLLIN, fd_callback);
 
@@ -510,6 +515,9 @@ extern "C" {
 
 ////////////////////////////////////////////////////////////////
 
+static char unknown[] = "<unknown>";
+const int unknown_len = 10;
+
 int fl_handle(const XEvent& thisevent)
 {
   XEvent xevent = thisevent;
@@ -555,7 +563,9 @@ int fl_handle(const XEvent& thisevent)
     }
     Fl::e_text = buffer ? (char*)buffer : (char *)"";
     Fl::e_length = bytesread;
-    fl_selection_requestor->handle(FL_PASTE);
+    int old_event = Fl::e_number;
+    fl_selection_requestor->handle(Fl::e_number = FL_PASTE);
+    Fl::e_number = old_event;
     // Detect if this paste is due to Xdnd by the property name (I use
     // XA_SECONDARY for that) and send an XdndFinished message. It is not
     // clear if this has to be delayed until now or if it can be done
@@ -632,6 +642,7 @@ int fl_handle(const XEvent& thisevent)
       in_a_window = true;
       fl_dnd_source_window = data[0];
       // version number is data[1]>>24
+//      printf("XdndEnter, version %ld\n", data[1] >> 24);
       if (data[1]&1) {
 	// get list of data types:
 	Atom actual; int format; unsigned long count, remaining;
@@ -655,8 +666,29 @@ int fl_handle(const XEvent& thisevent)
 	fl_dnd_source_types[2] = data[4];
 	fl_dnd_source_types[3] = 0;
       }
-      fl_dnd_type = fl_dnd_source_types[0]; // should pick text or url
+
+      // Loop through the source types and pick the first text type...
+      int i;
+
+      for (i = 0; fl_dnd_source_types[i]; i ++)
+      {
+//        printf("fl_dnd_source_types[%d] = %ld (%s)\n", i,
+//	       fl_dnd_source_types[i],
+//	       XGetAtomName(fl_display, fl_dnd_source_types[i]));
+
+        if (!strncmp(XGetAtomName(fl_display, fl_dnd_source_types[i]),
+	             "text/", 5))
+	  break;
+      }
+
+      if (fl_dnd_source_types[i])
+        fl_dnd_type = fl_dnd_source_types[i];
+      else
+        fl_dnd_type = fl_dnd_source_types[0];
+
       event = FL_DND_ENTER;
+      Fl::e_text = unknown;
+      Fl::e_length = unknown_len;
       break;
 
     } else if (message == fl_XdndPosition) {
@@ -672,6 +704,8 @@ int fl_handle(const XEvent& thisevent)
       fl_event_time = data[3];
       fl_dnd_source_action = data[4];
       fl_dnd_action = fl_XdndActionCopy;
+      Fl::e_text = unknown;
+      Fl::e_length = unknown_len;
       int accept = Fl::handle(FL_DND_DRAG, window);
       fl_sendClientMessage(data[0], fl_XdndStatus,
                            fl_xevent->xclient.window,
@@ -684,6 +718,8 @@ int fl_handle(const XEvent& thisevent)
     } else if (message == fl_XdndLeave) {
       fl_dnd_source_window = 0; // don't send a finished message to it
       event = FL_DND_LEAVE;
+      Fl::e_text = unknown;
+      Fl::e_length = unknown_len;
       break;
 
     } else if (message == fl_XdndDrop) {
@@ -692,6 +728,8 @@ int fl_handle(const XEvent& thisevent)
       fl_dnd_source_window = data[0];
       fl_event_time = data[2];
       Window to_window = fl_xevent->xclient.window;
+      Fl::e_text = unknown;
+      Fl::e_length = unknown_len;
       if (Fl::handle(FL_DND_RELEASE, window)) {
 	fl_selection_requestor = Fl::belowmouse();
 	XConvertSelection(fl_display, fl_XdndSelection,
@@ -1020,13 +1058,16 @@ void Fl_X::make_xid(Fl_Window* win, XVisualInfo *visual, Colormap colormap)
     // center windows in case window manager does not do anything:
 #ifdef FL_CENTER_WINDOWS
     if (!(win->flags() & Fl_Window::FL_FORCE_POSITION)) {
-      win->x(X = (Fl::w()-W)/2);
-      win->y(Y = (Fl::h()-H)/2);
+      win->x(X = scr_x+(scr_w-W)/2);
+      win->y(Y = scr_y+(scr_h-H)/2);
     }
 #endif // FL_CENTER_WINDOWS
 
     // force the window to be on-screen.  Usually the X window manager
     // does this, but a few don't, so we do it here for consistency:
+    int scr_x, scr_y, scr_w, scr_h;
+    Fl::screen_xywh(scr_x, scr_y, scr_w, scr_h, X, Y);
+
     if (win->border()) {
       // ensure border is on screen:
       // (assumme extremely minimal dimensions for this border)
@@ -1034,16 +1075,16 @@ void Fl_X::make_xid(Fl_Window* win, XVisualInfo *visual, Colormap colormap)
       const int left = 1;
       const int right = 1;
       const int bottom = 1;
-      if (X+W+right > Fl::w()) X = Fl::w()-right-W;
-      if (X-left < 0) X = left;
-      if (Y+H+bottom > Fl::h()) Y = Fl::h()-bottom-H;
-      if (Y-top < 0) Y = top;
+      if (X+W+right > scr_x+scr_w) X = scr_x+scr_w-right-W;
+      if (X-left < scr_x) X = scr_x+left;
+      if (Y+H+bottom > scr_y+scr_h) Y = scr_y+scr_h-bottom-H;
+      if (Y-top < scr_y) Y = scr_y+top;
     }
     // now insure contents are on-screen (more important than border):
-    if (X+W > Fl::w()) X = Fl::w()-W;
-    if (X < 0) X = 0;
-    if (Y+H > Fl::h()) Y = Fl::h()-H;
-    if (Y < 0) Y = 0;
+    if (X+W > scr_x+scr_w) X = scr_x+scr_w-W;
+    if (X < scr_x) X = scr_x;
+    if (Y+H > scr_y+scr_h) Y = scr_y+scr_h-H;
+    if (Y < scr_y) Y = scr_y;
   }
 
   ulong root = win->parent() ?
@@ -1114,6 +1155,14 @@ void Fl_X::make_xid(Fl_Window* win, XVisualInfo *visual, Colormap colormap)
       XSetTransientForHint(fl_display, xp->xid, fl_xid(wp));
       if (!wp->visible()) showit = 0; // guess that wm will not show it
     }
+   
+    // Make sure that borderless windows do not show in the task bar
+    if (!win->border()) {
+      Atom net_wm_state = XInternAtom (fl_display, "_NET_WM_STATE", 0);
+      Atom net_wm_state_skip_taskbar = XInternAtom (fl_display, "_NET_WM_STATE_SKIP_TASKBAR", 0);
+      XChangeProperty (fl_display, xp->xid, net_wm_state, XA_ATOM, 32, 
+          PropModeAppend, (unsigned char*) &net_wm_state_skip_taskbar, 1);
+    }
 
     // Make it receptive to DnD:
     long version = 4;
@@ -1140,7 +1189,9 @@ void Fl_X::make_xid(Fl_Window* win, XVisualInfo *visual, Colormap colormap)
   XMapWindow(fl_display, xp->xid);
   if (showit) {
     win->set_visible();
-    win->handle(FL_SHOW); // get child windows to appear
+    int old_event = Fl::e_number;
+    win->handle(Fl::e_number = FL_SHOW); // get child windows to appear
+    Fl::e_number = old_event;
     win->redraw();
   }
 }
@@ -1299,5 +1350,5 @@ void Fl_Window::make_current() {
 #endif
 
 //
-// End of "$Id: Fl_x.cxx,v 1.24.2.24.2.40 2004/11/20 13:52:47 easysw Exp $".
+// End of "$Id: Fl_x.cxx 4748 2006-01-15 02:26:54Z mike $".
 //
