@@ -1,9 +1,9 @@
 //
-// "$Id: filename_absolute.cxx,v 1.5.2.4.2.12 2004/04/11 04:38:59 easysw Exp $"
+// "$Id: filename_absolute.cxx 4660 2005-11-27 14:45:48Z mike $"
 //
 // Filename expansion routines for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2004 by Bill Spitzak and others.
+// Copyright 1998-2005 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,7 +20,9 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
 /* expand a file name by prepending current directory, deleting . and
@@ -35,12 +37,14 @@
 #include <ctype.h>
 #if defined(WIN32) && !defined(__CYGWIN__)
 # include <direct.h>
-//# define getcwd(a,b) _getdcwd(0,a,b)
+// Visual C++ 2005 incorrectly displays a warning about the use of POSIX APIs
+// on Windows, which is supposed to be POSIX compliant...
+#  define getcwd _getcwd
 #else
-# include <unistd.h>
-# ifdef __EMX__
-#  define getcwd _getcwd2
-# endif
+#  include <unistd.h>
+#  ifdef __EMX__
+#    define getcwd _getcwd2
+#  endif
 #endif
 
 #if defined(WIN32) || defined(__EMX__) && !defined(__CYGWIN__)
@@ -110,7 +114,7 @@ int					// O - 0 if no change, 1 if changed
 fl_filename_relative(char       *to,	// O - Relative filename
                      int        tolen,	// I - Size of "to" buffer
                      const char *from) {// I - Absolute filename
-  const char	*newslash;		// Directory separator
+  char		*newslash;		// Directory separator
   const char	*slash;			// Directory separator
   char		cwd[1024];		// Current directory
 
@@ -132,12 +136,15 @@ fl_filename_relative(char       *to,	// O - Relative filename
   }
 
 #if defined(WIN32) || defined(__EMX__)
+  for (newslash = strchr(cwd, '\\'); newslash; newslash = strchr(newslash + 1, '\\'))
+    *newslash = '/';
+
   if (!strcasecmp(from, cwd)) {
     strlcpy(to, ".", tolen);
     return (1);
   }
 
-  if (*from != *cwd) {
+  if (tolower(*from & 255) != tolower(*cwd & 255)) {
     // Not the same drive...
     strlcpy(to, from, tolen);
     return 0;
@@ -155,7 +162,7 @@ fl_filename_relative(char       *to,	// O - Relative filename
        slash ++, newslash ++)
     if (isdirsep(*slash) && isdirsep(*newslash)) continue;
 #if defined(WIN32) || defined(__EMX__) || defined(__APPLE__)
-    else if (tolower(*slash) != tolower(*newslash)) break;
+    else if (tolower(*slash & 255) != tolower(*newslash & 255)) break;
 #else
     else if (*slash != *newslash) break;
 #endif // WIN32 || __EMX__ || __APPLE__
@@ -186,5 +193,5 @@ fl_filename_relative(char       *to,	// O - Relative filename
 
 
 //
-// End of "$Id: filename_absolute.cxx,v 1.5.2.4.2.12 2004/04/11 04:38:59 easysw Exp $".
+// End of "$Id: filename_absolute.cxx 4660 2005-11-27 14:45:48Z mike $".
 //
