@@ -1,9 +1,9 @@
 //
-// "$Id: fl_draw.cxx,v 1.6.2.4.2.17 2004/10/18 20:40:36 easysw Exp $"
+// "$Id: fl_draw.cxx 4670 2005-11-29 08:49:56Z mike $"
 //
 // Label drawing code for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2004 by Bill Spitzak and others.
+// Copyright 1998-2005 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,7 +20,9 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
 // Implementation of fl_draw(const char*,int,int,int,int,Fl_Align)
@@ -36,6 +38,7 @@
 
 #include "flstring.h"
 #include <ctype.h>
+#include <math.h>
 
 #define MAXBUF 1024
 
@@ -295,19 +298,19 @@ void fl_measure(const char* str, int& w, int& h, int draw_symbols) {
          *symptr++ = *str++);
     *symptr = '\0';
     if (isspace(*str)) str++;
-    symwidth[0] = min(w,h);
+    symwidth[0] = h;
   }
 
   if (str && (p = strrchr(str, '@')) != NULL && p > (str + 1)) {
     strlcpy(symbol[1], p, sizeof(symbol[1]));
-    symwidth[1] = min(w,h);
+    symwidth[1] = h;
   }
 
   symtotal = symwidth[0] + symwidth[1];
   
   for (p = str, lines=0; p;) {
     e = expand(p, buf, w - symtotal, buflen, width, w != 0, draw_symbols);
-    if (int(width) > W) W = int(width);
+    if ((int)ceil(width) > W) W = (int)ceil(width);
     lines++;
     if (!*e || (*e == '@' && draw_symbols)) break;
     p = e;
@@ -325,5 +328,5 @@ void fl_measure(const char* str, int& w, int& h, int draw_symbols) {
 }
 
 //
-// End of "$Id: fl_draw.cxx,v 1.6.2.4.2.17 2004/10/18 20:40:36 easysw Exp $".
+// End of "$Id: fl_draw.cxx 4670 2005-11-29 08:49:56Z mike $".
 //
