@@ -1,9 +1,9 @@
 //
-// "$Id: fl_draw_image_mac.cxx,v 1.1.2.11 2004/09/10 00:07:52 matthiaswm Exp $"
+// "$Id: fl_draw_image_mac.cxx 4288 2005-04-16 00:13:17Z mike $"
 //
 // MacOS image drawing code for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2004 by Bill Spitzak and others.
+// Copyright 1998-2005 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,7 +20,9 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
 ////////////////////////////////////////////////////////////////
@@ -165,8 +167,8 @@ static void innards(const uchar *buf, int X, int Y, int W, int H,
     }
   }
 #elif defined(__APPLE_QUARTZ__)
-  void *array = buf;
-  uchar *tmpBuf;
+  const void *array = buf;
+  uchar *tmpBuf = 0;
   if (cb) {
     tmpBuf = new uchar[ H*W*delta ];
     for (int i=0; i<H; i++) {
@@ -264,5 +266,5 @@ void fl_rectf(int x, int y, int w, int h, uchar r, uchar g, uchar b) {
 }
 
 //
-// End of "$Id: fl_draw_image_mac.cxx,v 1.1.2.11 2004/09/10 00:07:52 matthiaswm Exp $".
+// End of "$Id: fl_draw_image_mac.cxx 4288 2005-04-16 00:13:17Z mike $".
 //
