@@ -1,9 +1,9 @@
 //
-// "$Id: fl_draw_pixmap.cxx,v 1.4.2.8.2.16 2004/09/11 19:32:43 easysw Exp $"
+// "$Id: fl_draw_pixmap.cxx 4723 2005-12-30 10:13:17Z matt $"
 //
 // Pixmap drawing code for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2004 by Bill Spitzak and others.
+// Copyright 1998-2005 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,7 +20,9 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
 // Implemented without using the xpm library (which I can't use because
@@ -261,15 +263,16 @@ int fl_draw_pixmap(const char*const* di, int x, int y, Fl_Color bg) {
     for (int Y = 0; Y < d.h; Y++) {
       const uchar* p = data[Y];
       if (chars_per_pixel <= 1) {
+	int dw = d.w;
 	for (int X = 0; X < W; X++) {
-	  uchar b = (*p++ != transparent_index);
-	  if (*p++ != transparent_index) b |= 2;
-	  if (*p++ != transparent_index) b |= 4;
-	  if (*p++ != transparent_index) b |= 8;
-	  if (*p++ != transparent_index) b |= 16;
-	  if (*p++ != transparent_index) b |= 32;
-	  if (*p++ != transparent_index) b |= 64;
-	  if (*p++ != transparent_index) b |= 128;
+	  uchar b = (dw-->0 && *p++ != transparent_index);
+	  if (dw-->0 && *p++ != transparent_index) b |= 2;
+	  if (dw-->0 && *p++ != transparent_index) b |= 4;
+	  if (dw-->0 && *p++ != transparent_index) b |= 8;
+	  if (dw-->0 && *p++ != transparent_index) b |= 16;
+	  if (dw-->0 && *p++ != transparent_index) b |= 32;
+	  if (dw-->0 && *p++ != transparent_index) b |= 64;
+	  if (dw-->0 && *p++ != transparent_index) b |= 128;
 	  *bitmap++ = b;
 	}
       } else {
@@ -334,5 +337,5 @@ int fl_draw_pixmap(const char*const* di, int x, int y, Fl_Color bg) {
 }
 
 //
-// End of "$Id: fl_draw_pixmap.cxx,v 1.4.2.8.2.16 2004/09/11 19:32:43 easysw Exp $".
+// End of "$Id: fl_draw_pixmap.cxx 4723 2005-12-30 10:13:17Z matt $".
 //
