@@ -1,9 +1,9 @@
 //
-// "$Id: fl_font_mac.cxx,v 1.1.2.23 2004/09/13 00:30:08 easysw Exp $"
+// "$Id: fl_font_mac.cxx 4587 2005-10-09 16:27:45Z matt $"
 //
 // MacOS font selection routines for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2004 by Bill Spitzak and others.
+// Copyright 1998-2005 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,7 +20,9 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
 #include <config.h>
@@ -228,6 +230,10 @@ static int n_iso_buf = 0;
 
 // this function must be available for OpenGL character drawing as well
 const char *fl_iso2macRoman(const char *s, int n) {
+  // do not do a text lookup for 'Symbol' or 'WebDings'. This fails
+  // if the user assigns a new font to these numbers though.
+  if (fl_font_ == 12 || fl_font_ == 15)
+    return s;
   if (n>n_iso_buf) {
     if (iso_buf) free(iso_buf);
     iso_buf = (char*)malloc(n+500);
@@ -296,5 +302,5 @@ void fl_draw(const char *str, int n, float x, float y) {
 }
 
 //
-// End of "$Id: fl_font_mac.cxx,v 1.1.2.23 2004/09/13 00:30:08 easysw Exp $".
+// End of "$Id: fl_font_mac.cxx 4587 2005-10-09 16:27:45Z matt $".
 //
