@@ -1,9 +1,9 @@
 //
-// "$Id: fl_font_win32.cxx,v 1.9.2.3.2.9 2004/09/11 18:06:29 easysw Exp $"
+// "$Id: fl_font_win32.cxx 4329 2005-05-12 13:37:49Z mike $"
 //
 // WIN32 font selection routines for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2004 by Bill Spitzak and others.
+// Copyright 1998-2005 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,7 +20,9 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
 Fl_FontSize::Fl_FontSize(const char* name, int size) {
@@ -153,7 +155,7 @@ double fl_width(uchar c) {
 
 void fl_draw(const char* str, int n, int x, int y) {
   COLORREF oldColor = SetTextColor(fl_gc, fl_RGB());
-  SelectObject(fl_gc, fl_fontsize->fid);
+  if (fl_fontsize) SelectObject(fl_gc, fl_fontsize->fid);
   TextOut(fl_gc, x, y, str, n);
   SetTextColor(fl_gc, oldColor);
 }
@@ -163,5 +165,5 @@ void fl_draw(const char* str, int n, float x, float y) {
 }
 
 //
-// End of "$Id: fl_font_win32.cxx,v 1.9.2.3.2.9 2004/09/11 18:06:29 easysw Exp $".
+// End of "$Id: fl_font_win32.cxx 4329 2005-05-12 13:37:49Z mike $".
 //
