@@ -1,9 +1,9 @@
 //
-// "$Id: fl_shortcut.cxx,v 1.4.2.9.2.14 2004/09/21 13:35:40 easysw Exp $"
+// "$Id: fl_shortcut.cxx 4727 2005-12-30 14:11:04Z matt $"
 //
 // Shortcut support routines for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2004 by Bill Spitzak and others.
+// Copyright 1998-2005 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,7 +20,9 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
 // Code to test and parse fltk shortcut numbers.
@@ -52,6 +54,13 @@
 int Fl::test_shortcut(int shortcut) {
   if (!shortcut) return 0;
 
+  int v = shortcut & 0xffff;
+  if (v > 32 && v < 0x7f || v > 0xa0 && v <= 0xff) {
+    if (isupper(v)) {
+      shortcut |= FL_SHIFT;
+    }
+  }
+
   int shift = Fl::event_state();
   // see if any required shift flags are off:
   if ((shortcut&shift) != (shortcut&0x7fff0000)) return 0;
@@ -116,6 +125,13 @@ const char * fl_shortcut_label(int shortcut) {
   static char buf[20];
   char *p = buf;
   if (!shortcut) {*p = 0; return buf;}
+  // fix upper case shortcuts
+  int v = shortcut & 0xffff;
+  if (v > 32 && v < 0x7f || v > 0xa0 && v <= 0xff) {
+    if (isupper(v)) {
+      shortcut |= FL_SHIFT;
+    }
+  }
 #ifdef __APPLE__
   // \todo Mac :  we might want to change the symbols for Mac users - consider drawing Apple Symbols... .
   if (shortcut & FL_SHIFT) {strcpy(p,"Shift+"); p += 6;} //: Mac hollow up arrow
@@ -153,7 +169,7 @@ const char * fl_shortcut_label(int shortcut) {
       *p++ = uchar(key & 127);
     } else {
       // if none found, use the keystroke as a match:
-      *p++ = uchar(key);
+      *p++ = uchar(toupper(key & 255));
     }
   }
   *p = 0;
@@ -163,7 +179,7 @@ const char * fl_shortcut_label(int shortcut) {
   if (key == FL_Enter || key == '\r') q="Enter";  // don't use Xlib's "Return":
   else if (key > 32 && key < 0x100) q = 0;
   else q = XKeysymToString(key);
-  if (!q) {*p++ = uchar(key); *p = 0; return buf;}
+  if (!q) {*p++ = uchar(toupper(key & 255)); *p = 0; return buf;}
   if (p > buf) {strcpy(p,q); return buf;} else return q;
 #endif
 }
@@ -201,5 +217,5 @@ int Fl_Widget::test_shortcut() {
 }
 
 //
-// End of "$Id: fl_shortcut.cxx,v 1.4.2.9.2.14 2004/09/21 13:35:40 easysw Exp $".
+// End of "$Id: fl_shortcut.cxx 4727 2005-12-30 14:11:04Z matt $".
 //
