@@ -1,9 +1,9 @@
 //
-// "$Id: forms_pixmap.cxx,v 1.4.2.3 2001/01/22 15:13:41 easysw Exp $"
+// "$Id: forms_pixmap.cxx 4288 2005-04-16 00:13:17Z mike $"
 //
 // Forms pixmap drawing routines for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2001 by Bill Spitzak and others.
+// Copyright 1998-2005 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,14 +20,16 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
 #include <FL/forms.H>
 
 Fl_FormsPixmap::Fl_FormsPixmap(
-  Fl_Boxtype t, int x, int y, int w, int h, const char* l)
-: Fl_Widget(x, y, w, h, l) {
+  Fl_Boxtype t, int X, int Y, int W, int H, const char* l)
+: Fl_Widget(X, Y, W, H, l) {
   box(t);
   b = 0;
   color(FL_BLACK);
@@ -46,5 +48,5 @@ void Fl_FormsPixmap::draw() {
 }
 
 //
-// End of "$Id: forms_pixmap.cxx,v 1.4.2.3 2001/01/22 15:13:41 easysw Exp $".
+// End of "$Id: forms_pixmap.cxx 4288 2005-04-16 00:13:17Z mike $".
 //
