@@ -1,12 +1,12 @@
 //
-// "$Id: checkers.cxx,v 1.9.2.7.2.5 2004/04/11 04:39:00 easysw Exp $"
+// "$Id: checkers.cxx 4288 2005-04-16 00:13:17Z mike $"
 //
 // Checkers game for the Fast Light Tool Kit (FLTK).
 //
 // Hours of fun: the FLTK checkers game!
 // Based on a very old algorithim, but it still works!
 //
-// Copyright 1998-2004 by Bill Spitzak and others.
+// Copyright 1998-2005 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -23,7 +23,9 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
 const char* copyright = 
@@ -56,7 +58,7 @@ const char* copyright =
 #define FLTK
 //#define VT100
 
-#include "../src/flstring.h"
+#include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <stdarg.h>
@@ -221,7 +223,7 @@ void evaluateboard(node *n,int print) {
 
   if (!n->who) tb = b;	// move was black's
   else {
-    for (int i=0; i<45; i++) flipboard[44-i] = flip[b[i]];
+    for (int i=0; i<45; i++) flipboard[44-i] = flip[(int)b[i]];
     tb = flipboard;
   }
 
@@ -413,7 +415,7 @@ void movepiece(node* f, int i, node* jnode) {
   static char jumphappened;
 
   for (int k=0; k<4; k++) {
-    int direction = offset[b[i]][k];
+    int direction = offset[(int)b[i]][k];
     if (!direction) break;
     int j = i+direction;
     if (b[j] == EMPTY) {
@@ -1355,5 +1357,5 @@ int main(int argc, char **argv) {
 }
 
 //
-// End of "$Id: checkers.cxx,v 1.9.2.7.2.5 2004/04/11 04:39:00 easysw Exp $".
+// End of "$Id: checkers.cxx 4288 2005-04-16 00:13:17Z mike $".
 //
