@@ -1,13 +1,13 @@
 //
-// "$Id: fractals.cxx,v 1.5.2.6 2001/04/30 17:17:01 easysw Exp $"
+// "$Id: fractals.cxx 4342 2005-05-12 19:16:27Z mike $"
 //
 // Fractal drawing demo for the Fast Light Tool Kit (FLTK).
 //
 // This is a GLUT demo program, with modifications to
-// demonstrate how to add fltk controls to a glut program.   The glut
-// code is unchanged except for the end (search for fltk to find changes).
+// demonstrate how to add FLTK controls to a GLUT program.   The GLUT
+// code is unchanged except for the end (search for FLTK to find changes).
 //
-// Copyright 1998-2001 by Bill Spitzak and others.
+// Copyright 1998-2005 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -24,15 +24,17 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
-#include <config.h>
+#include "config.h"
 #if !HAVE_GL || !HAVE_GL_GLU_H
 #include <FL/Fl.H>
 #include <FL/fl_message.H>
 int main(int, char**) {
-  fl_alert("This demo does not work without GL and GLU");
+  fl_alert("This demo does not work without GL and GLU (%d)");
   return 1;
 }
 #else
@@ -62,7 +64,11 @@ int main(int, char**) {
  */
 
 #include <FL/glut.H>
-#include <GL/glu.h> // added for fltk
+#ifdef __APPLE__
+#  include <OpenGL/glu.h>
+#else
+#  include <GL/glu.h> // added for FLTK
+#endif
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -72,11 +78,14 @@ int main(int, char**) {
 
 #include <time.h>  /* for random seed */
 
-#include "fracviewer.c" // changed from .h for fltk
+#include "fracviewer.h"
 
 #if defined(WIN32) || defined(__EMX__)
-#define drand48() (((float) rand())/((float) RAND_MAX))
-#define srand48(x) (srand((x)))
+#  define drand48() (((float) rand())/((float) RAND_MAX))
+#  define srand48(x) (srand((x)))
+#elif defined __APPLE__
+#  define drand48() (((float) rand())/((float) RAND_MAX))
+#  define srand48(x) (srand((x)))
 #endif
 
 typedef enum { NOTALLOWED, MOUNTAIN, TREE, ISLAND, BIGMTN, STEM, LEAF, 
@@ -603,26 +612,30 @@ void myGLInit(void)
 /************************ GLUT STUFF ***************************/
 /***************************************************************/
 
+int winwidth = 1;
+int winheight = 1;
+
 void reshape(int w, int h)
 {
   glViewport(0,0,w,h);
-  glMatrixMode(GL_PROJECTION);
-  glLoadIdentity();
-  gluPerspective(60.0, (GLdouble)w/h, 0.01, 100);
-  glPushMatrix();
-  glMatrixMode(GL_MODELVIEW);
-  glFlush();
+
+  winwidth  = w;
+  winheight = h;
 }
 
 void display(void)
-{ 
+{
+  time_t curtime;
+  char buf[255];
+  static time_t fpstime = 0;
+  static int fpscount = 0;
+  static int fps = 0;
+
   glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
-  glFlush();
 
   glMatrixMode(GL_PROJECTION);
-  glPopMatrix();
-  glPushMatrix();  /* clear of last viewing xform, leaving perspective */
-
+  glLoadIdentity();
+  gluPerspective(60.0, (GLdouble)winwidth/winheight, 0.01, 100);
   agvViewTransform();
 
   glMatrixMode(GL_MODELVIEW);
@@ -638,8 +651,31 @@ void display(void)
   if (DrawAxes)
     glCallList(AXES);
 
-  glutSwapBuffers();
-  glFlush();
+  glMatrixMode(GL_PROJECTION);
+  glLoadIdentity();
+  gluOrtho2D(0.0, winwidth, 0.0, winheight);
+
+  sprintf(buf, "FPS=%d", fps);
+  glColor3f(1.0f, 1.0f, 1.0f);
+  gl_font(FL_HELVETICA, 12);
+  gl_draw(buf, 10, 10);
+
+  //
+  // Use glFinish() instead of glFlush() to avoid getting many frames
+  // ahead of the display (problem with some Linux OpenGL implementations...)
+  //
+
+  glFinish();
+
+  // Update frames-per-second
+  fpscount ++;
+  curtime = time(NULL);
+  if ((curtime - fpstime) >= 2)
+  {
+    fps      = (fps + fpscount / (curtime - fpstime)) / 2;
+    fpstime  = curtime;
+    fpscount = 0;
+  }
 }
 
 void visible(int v)
@@ -735,7 +771,7 @@ void MenuInit(void)
 /**************************** MAIN *****************************/
 /***************************************************************/
 
-// fltk-style callbacks to Glut menu callback translators:
+// FLTK-style callbacks to Glut menu callback translators:
 void setlevel(Fl_Widget*, void *value) {setlevel(long(value));}
 
 void choosefract(Fl_Widget*, void *value) {choosefract(long(value));}
@@ -748,9 +784,9 @@ void handlemenu(Fl_Widget*, void *value) {handlemenu(long(value));}
 
 int main(int argc, char** argv)
 {
-//  glutInit(&argc, argv); // this line removed for fltk
+//  glutInit(&argc, argv); // this line removed for FLTK
 
-  // create fltk window:
+  // create FLTK window:
   Fl_Window window(512+20, 512+100);
   window.resizable(window);
 
@@ -806,5 +842,5 @@ int main(int argc, char** argv)
 #endif
 
 //
-// End of "$Id: fractals.cxx,v 1.5.2.6 2001/04/30 17:17:01 easysw Exp $".
+// End of "$Id: fractals.cxx 4342 2005-05-12 19:16:27Z mike $".
 //
