@@ -1,9 +1,9 @@
 //
-// "$Id: gl_overlay.cxx,v 1.4.2.3.2.3 2004/04/11 04:39:01 easysw Exp $"
+// "$Id: gl_overlay.cxx 4288 2005-04-16 00:13:17Z mike $"
 //
 // OpenGL overlay test program for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2004 by Bill Spitzak and others.
+// Copyright 1998-2005 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,10 +20,12 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
-#include <config.h>
+#include "config.h"
 #include <FL/Fl.H>
 #include <FL/Fl_Window.H>
 #include <FL/Fl_Hor_Slider.H>
@@ -151,5 +153,5 @@ int main(int argc, char **argv) {
 }
 
 //
-// End of "$Id: gl_overlay.cxx,v 1.4.2.3.2.3 2004/04/11 04:39:01 easysw Exp $".
+// End of "$Id: gl_overlay.cxx 4288 2005-04-16 00:13:17Z mike $".
 //
