@@ -1,9 +1,9 @@
 //
-// "$Id: input.cxx,v 1.5.2.4.2.7 2004/04/11 04:39:01 easysw Exp $"
+// "$Id: input.cxx 4626 2005-11-02 13:57:56Z matt $"
 //
 // Input field test program for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2004 by Bill Spitzak and others.
+// Copyright 1998-2005 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,7 +20,9 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
 #include <stdio.h>
@@ -60,9 +62,9 @@ void button_cb(Fl_Widget *,void *) {
 void color_cb(Fl_Widget* button, void* v) {
   Fl_Color c;
   switch ((int)v) {
-  case 0: c = FL_WHITE; break;
+  case 0: c = FL_BACKGROUND2_COLOR; break;
   case 1: c = FL_SELECTION_COLOR; break;
-  default: c = FL_BLACK; break;
+  default: c = FL_FOREGROUND_COLOR; break;
   }
   uchar r,g,b; Fl::get_color(c, r,g,b);
   if (fl_color_chooser(0,r,g,b)) {
@@ -73,13 +75,17 @@ void color_cb(Fl_Widget* button, void* v) {
 }
 
 int main(int argc, char **argv) {
+  // the following two lines set the correct color scheme, so that 
+  // calling fl_contrast below will return good results
+  Fl::args(argc, argv);
+  Fl::get_system_colors();
   Fl_Window *window = new Fl_Window(400,400);
 
   int y = 10;
   input[0] = new Fl_Input(70,y,300,30,"Normal:"); y += 35;
   input[0]->tooltip("Normal input field");
   // input[0]->cursor_color(FL_SELECTION_COLOR);
-  //  input[0]->maximum_size(20);
+  // input[0]->maximum_size(20);
   // input[0]->static_value("this is a testgarbage");
   input[1] = new Fl_Float_Input(70,y,300,30,"Float:"); y += 35;
   input[1]->tooltip("Input field for floating-point number");
@@ -132,5 +138,5 @@ int main(int argc, char **argv) {
 }
 
 //
-// End of "$Id: input.cxx,v 1.5.2.4.2.7 2004/04/11 04:39:01 easysw Exp $".
+// End of "$Id: input.cxx 4626 2005-11-02 13:57:56Z matt $".
 //
