@@ -1,5 +1,5 @@
 //
-// "$Id: keyboard.cxx,v 1.5.2.3.2.7 2004/04/11 04:39:01 easysw Exp $"
+// "$Id: keyboard.cxx 4301 2005-04-28 17:48:04Z mike $"
 //
 // Keyboard/event test program for the Fast Light Tool Kit (FLTK).
 //
@@ -17,7 +17,7 @@
 //
 // On IRIX the backslash key does not work.  A bug in XKeysymToKeycode?
 //
-// Copyright 1998-2004 by Bill Spitzak and others.
+// Copyright 1998-2005 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -34,7 +34,9 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
 
@@ -60,7 +62,7 @@ int MyWindow::handle(int msg) {
   return 0;
 }
 
-struct {int n; const char* text;} table[] = {
+struct keycode_table{int n; const char* text;} table[] = {
   {FL_Escape, "FL_Escape"},
   {FL_BackSpace, "FL_BackSpace"},
   {FL_Tab, "FL_Tab"},
@@ -139,5 +141,5 @@ int main(int argc, char** argv) {
 }
 
 //
-// End of "$Id: keyboard.cxx,v 1.5.2.3.2.7 2004/04/11 04:39:01 easysw Exp $".
+// End of "$Id: keyboard.cxx 4301 2005-04-28 17:48:04Z mike $".
 //
