@@ -1,9 +1,9 @@
 //
-// "$Id: menubar.cxx,v 1.6.2.8.2.7 2004/04/11 04:39:01 easysw Exp $"
+// "$Id: menubar.cxx 4763 2006-01-16 23:22:32Z matt $"
 //
 // Menubar test program for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2004 by Bill Spitzak and others.
+// Copyright 1998-2005 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,7 +20,9 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
 #include <FL/Fl.H>
@@ -32,7 +34,7 @@
 #include <FL/Fl_Choice.H>
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
+#include "../src/flstring.h"
 #include <FL/fl_draw.H>
 
 void window_cb(Fl_Widget* w, void*) {
@@ -158,7 +160,7 @@ Fl_Menu_Item pulldown[] = {
   {"Red",	FL_ALT+'r'},
   {"Green",	FL_ALT+'g'},
   {"Blue",	FL_ALT+'b'},
-  {"Strange",	FL_ALT+'s'},
+  {"Strange",	FL_ALT+'s', 0, 0, FL_MENU_INACTIVE},
   {"&Charm",	FL_ALT+'c'},
   {"Truth",	FL_ALT+'t'},
   {"Beauty",	FL_ALT+'b'},
@@ -203,5 +205,5 @@ int main(int argc, char **argv) {
 }
 
 //
-// End of "$Id: menubar.cxx,v 1.6.2.8.2.7 2004/04/11 04:39:01 easysw Exp $".
+// End of "$Id: menubar.cxx 4763 2006-01-16 23:22:32Z matt $".
 //
