@@ -1,9 +1,9 @@
 //
-// "$Id: message.cxx,v 1.5.2.3 2001/01/22 15:13:41 easysw Exp $"
+// "$Id: message.cxx 4626 2005-11-02 13:57:56Z matt $"
 //
 // Message test program for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2001 by Bill Spitzak and others.
+// Copyright 1998-2005 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,7 +20,9 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
 #include <FL/Fl.H>
@@ -28,16 +30,19 @@
 #include <FL/fl_ask.H>
 #include <stdio.h>
 
-int main(int, char **) {
+int main(int argc, char **argv) {
+  Fl::scheme(NULL);
+  Fl::args(argc, argv);
+  Fl::get_system_colors();
 
-  fl_message("Spelling check sucessfull, %d errors found with %g%% confidence",
+  fl_message("Spelling check sucessful, %d errors found with %g%% confidence",
 	     1002, 100*(15/77.0));
 
-  fl_alert("Quantum fluctuations in the space-time continuim detected, "
+  fl_alert("Quantum fluctuations in the space-time continuum detected, "
 	   "you have %g seconds to comply.", 10.0);
 
-  printf("fl_ask returned %d\n",
-    fl_ask("Do you really want to %s?", "continue"));
+  printf("fl_choice returned %d\n",
+    fl_choice("Do you really want to %s?", "No", "Yes", 0L, "continue"));
 
   printf("fl_choice returned %d\n",
     fl_choice("Choose one of the following:","choice0","choice1","choice2"));
@@ -54,5 +59,5 @@ int main(int, char **) {
 }
 
 //
-// End of "$Id: message.cxx,v 1.5.2.3 2001/01/22 15:13:41 easysw Exp $".
+// End of "$Id: message.cxx 4626 2005-11-02 13:57:56Z matt $".
 //
