@@ -1,9 +1,9 @@
 //
-// "$Id: threads.h,v 1.1.2.8 2004/11/20 03:44:18 easysw Exp $"
+// "$Id: threads.h 4748 2006-01-15 02:26:54Z mike $"
 //
 // Simple threading API for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-2004 by Bill Spitzak and others.
+// Copyright 1998-2006 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,7 +20,9 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+// Please report all bugs and problems on the following page:
+//
+//     http://www.fltk.org/str.php
 //
 
 // Inline classes to provide portable support for threads and mutexes.
@@ -48,8 +50,7 @@
 
 typedef pthread_t Fl_Thread;
 
-static int fl_create_thread(Fl_Thread& t, void *(*f) (void *), void* p)
-{
+static int fl_create_thread(Fl_Thread& t, void *(*f) (void *), void* p) {
   return pthread_create((pthread_t*)&t, 0, f, p);
 }
 
@@ -76,5 +77,5 @@ static int fl_create_thread(Fl_Thread& t, void *(*f) (void *), void* p) {
 #endif // !Threads_h
 
 //
-// End of "$Id: threads.h,v 1.1.2.8 2004/11/20 03:44:18 easysw Exp $".
+// End of "$Id: threads.h 4748 2006-01-15 02:26:54Z mike $".
 //
